# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/wasm/v1/wasm.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ibc/lightclients/wasm/v1/wasm.proto\x12\x18ibc.lightclients.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fibc/core/client/v1/client.proto\"\x8a\x01\n\x0b\x43lientState\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x1a\n\x08\x63hecksum\x18\x02 \x01(\x0cR\x08\x63hecksum\x12\x45\n\rlatest_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0clatestHeight:\x04\x88\xa0\x1f\x00\"*\n\x0e\x43onsensusState\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta:\x04\x88\xa0\x1f\x00\")\n\rClientMessage\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta:\x04\x88\xa0\x1f\x00\"-\n\tChecksums\x12\x1c\n\tchecksums\x18\x01 \x03(\x0cR\tchecksums:\x02\x18\x01\x42\xea\x01\n\x1c\x63om.ibc.lightclients.wasm.v1B\tWasmProtoP\x01Z<github.com/cosmos/ibc-go/modules/light-clients/08-wasm/types\xa2\x02\x03ILW\xaa\x02\x18Ibc.Lightclients.Wasm.V1\xca\x02\x18Ibc\\Lightclients\\Wasm\\V1\xe2\x02$Ibc\\Lightclients\\Wasm\\V1\\GPBMetadata\xea\x02\x1bIbc::Lightclients::Wasm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.wasm.v1.wasm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ibc.lightclients.wasm.v1B\tWasmProtoP\001Z<github.com/cosmos/ibc-go/modules/light-clients/08-wasm/types\242\002\003ILW\252\002\030Ibc.Lightclients.Wasm.V1\312\002\030Ibc\\Lightclients\\Wasm\\V1\342\002$Ibc\\Lightclients\\Wasm\\V1\\GPBMetadata\352\002\033Ibc::Lightclients::Wasm::V1'
  _globals['_CLIENTSTATE'].fields_by_name['latest_height']._loaded_options = None
  _globals['_CLIENTSTATE'].fields_by_name['latest_height']._serialized_options = b'\310\336\037\000'
  _globals['_CLIENTSTATE']._loaded_options = None
  _globals['_CLIENTSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_CONSENSUSSTATE']._loaded_options = None
  _globals['_CONSENSUSSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTMESSAGE']._loaded_options = None
  _globals['_CLIENTMESSAGE']._serialized_options = b'\210\240\037\000'
  _globals['_CHECKSUMS']._loaded_options = None
  _globals['_CHECKSUMS']._serialized_options = b'\030\001'
  _globals['_CLIENTSTATE']._serialized_start=121
  _globals['_CLIENTSTATE']._serialized_end=259
  _globals['_CONSENSUSSTATE']._serialized_start=261
  _globals['_CONSENSUSSTATE']._serialized_end=303
  _globals['_CLIENTMESSAGE']._serialized_start=305
  _globals['_CLIENTMESSAGE']._serialized_end=346
  _globals['_CHECKSUMS']._serialized_start=348
  _globals['_CHECKSUMS']._serialized_end=393
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/event_provider_api.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!exchange/event_provider_api.proto\x12\x12\x65vent_provider_api\"\x18\n\x16GetLatestHeightRequest\"~\n\x17GetLatestHeightResponse\x12\x0c\n\x01v\x18\x01 \x01(\tR\x01v\x12\x0c\n\x01s\x18\x02 \x01(\tR\x01s\x12\x0c\n\x01\x65\x18\x03 \x01(\tR\x01\x65\x12\x39\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32%.event_provider_api.LatestBlockHeightR\x04\x64\x61ta\"?\n\x11LatestBlockHeight\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x12\n\x04time\x18\x02 \x01(\x12R\x04time\"\x1b\n\x19StreamLatestHeightRequest\"H\n\x1aStreamLatestHeightResponse\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x12\n\x04time\x18\x02 \x01(\x12R\x04time\"L\n\x18StreamBlockEventsRequest\x12\x18\n\x07\x62\x61\x63kend\x18\x01 \x01(\tR\x07\x62\x61\x63kend\x12\x16\n\x06height\x18\x02 \x01(\x11R\x06height\"N\n\x19StreamBlockEventsResponse\x12\x31\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x19.event_provider_api.BlockR\x06\x62locks\"\x8a\x01\n\x05\x42lock\x12\x16\n\x06height\x18\x01 \x01(\x12R\x06height\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12\x36\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1e.event_provider_api.BlockEventR\x06\x65vents\x12\x17\n\x07in_sync\x18\x04 \x01(\x08R\x06inSync\"j\n\nBlockEvent\x12\x19\n\x08type_url\x18\x01 \x01(\tR\x07typeUrl\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\x12\x17\n\x07tx_hash\x18\x03 \x01(\x0cR\x06txHash\x12\x12\n\x04mode\x18\x04 \x01(\tR\x04mode\"s\n\x18GetBlockEventsRPCRequest\x12\x18\n\x07\x62\x61\x63kend\x18\x01 \x01(\tR\x07\x62\x61\x63kend\x12\x16\n\x06height\x18\x02 \x01(\x11R\x06height\x12%\n\x0ehuman_readable\x18\x03 \x01(\x08R\rhumanReadable\"\xb7\x01\n\x19GetBlockEventsRPCResponse\x12\x0c\n\x01v\x18\x01 \x01(\tR\x01v\x12\x0c\n\x01s\x18\x02 \x01(\tR\x01s\x12\x0c\n\x01\x65\x18\x03 \x01(\tR\x01\x65\x12\x36\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\".event_provider_api.BlockEventsRPCR\x04\x64\x61ta\x12\x38\n\x05\x62lock\x18\x05 \x01(\x0b\x32\".event_provider_api.BasicBlockInfoR\x05\x62lock\"\xca\x01\n\x0e\x42lockEventsRPC\x12\x14\n\x05types\x18\x01 \x03(\tR\x05types\x12\x16\n\x06\x65vents\x18\x02 \x03(\x0cR\x06\x65vents\x12M\n\ttx_hashes\x18\x03 \x03(\x0b\x32\x30.event_provider_api.BlockEventsRPC.TxHashesEntryR\x08txHashes\x1a;\n\rTxHashesEntry\x12\x10\n\x03key\x18\x01 \x01(\x11R\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value:\x02\x38\x01\"Z\n\x0e\x42\x61sicBlockInfo\x12\x16\n\x06height\x18\x01 \x01(\x12R\x06height\x12\x1c\n\ttimestamp\x18\x02 \x01(\x12R\ttimestamp\x12\x12\n\x04time\x18\x03 \x01(\tR\x04time\"e\n\x19GetCustomEventsRPCRequest\x12\x18\n\x07\x62\x61\x63kend\x18\x01 \x01(\tR\x07\x62\x61\x63kend\x12\x16\n\x06height\x18\x02 \x01(\x11R\x06height\x12\x16\n\x06\x65vents\x18\x03 \x01(\tR\x06\x65vents\"\xb8\x01\n\x1aGetCustomEventsRPCResponse\x12\x0c\n\x01v\x18\x01 \x01(\tR\x01v\x12\x0c\n\x01s\x18\x02 \x01(\tR\x01s\x12\x0c\n\x01\x65\x18\x03 \x01(\tR\x01\x65\x12\x36\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\".event_provider_api.BlockEventsRPCR\x04\x64\x61ta\x12\x38\n\x05\x62lock\x18\x05 \x01(\x0b\x32\".event_provider_api.BasicBlockInfoR\x05\x62lock\"T\n\x19GetABCIBlockEventsRequest\x12\x16\n\x06height\x18\x01 \x01(\x11R\x06height\x12\x1f\n\x0b\x65vent_types\x18\x02 \x03(\tR\neventTypes\"\x81\x01\n\x1aGetABCIBlockEventsResponse\x12\x0c\n\x01v\x18\x01 \x01(\tR\x01v\x12\x0c\n\x01s\x18\x02 \x01(\tR\x01s\x12\x0c\n\x01\x65\x18\x03 \x01(\tR\x01\x65\x12\x39\n\traw_block\x18\x04 \x01(\x0b\x32\x1c.event_provider_api.RawBlockR\x08rawBlock\"\xcc\x02\n\x08RawBlock\x12\x16\n\x06height\x18\x01 \x01(\x12R\x06height\x12\x1d\n\nblock_time\x18\x05 \x01(\tR\tblockTime\x12\'\n\x0f\x62lock_timestamp\x18\x06 \x01(\x12R\x0e\x62lockTimestamp\x12J\n\x0btxs_results\x18\x02 \x03(\x0b\x32).event_provider_api.ABCIResponseDeliverTxR\ntxsResults\x12K\n\x12\x62\x65gin_block_events\x18\x03 \x03(\x0b\x32\x1d.event_provider_api.ABCIEventR\x10\x62\x65ginBlockEvents\x12G\n\x10\x65nd_block_events\x18\x04 \x03(\x0b\x32\x1d.event_provider_api.ABCIEventR\x0e\x65ndBlockEvents\"\xf9\x01\n\x15\x41\x42\x43IResponseDeliverTx\x12\x12\n\x04\x63ode\x18\x01 \x01(\x11R\x04\x63ode\x12\x10\n\x03log\x18\x02 \x01(\tR\x03log\x12\x12\n\x04info\x18\x03 \x01(\tR\x04info\x12\x1d\n\ngas_wanted\x18\x04 \x01(\x12R\tgasWanted\x12\x19\n\x08gas_used\x18\x05 \x01(\x12R\x07gasUsed\x12\x35\n\x06\x65vents\x18\x06 \x03(\x0b\x32\x1d.event_provider_api.ABCIEventR\x06\x65vents\x12\x1c\n\tcodespace\x18\x07 \x01(\tR\tcodespace\x12\x17\n\x07tx_hash\x18\x08 \x01(\x0cR\x06txHash\"b\n\tABCIEvent\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x41\n\nattributes\x18\x02 \x03(\x0b\x32!.event_provider_api.ABCIAttributeR\nattributes\"7\n\rABCIAttribute\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\";\n!GetABCIBlockEventsAtHeightRequest\x12\x16\n\x06height\x18\x01 \x01(\x11R\x06height\"\x89\x01\n\"GetABCIBlockEventsAtHeightResponse\x12\x0c\n\x01v\x18\x01 \x01(\tR\x01v\x12\x0c\n\x01s\x18\x02 \x01(\tR\x01s\x12\x0c\n\x01\x65\x18\x03 \x01(\tR\x01\x65\x12\x39\n\traw_block\x18\x04 \x01(\x0b\x32\x1c.event_provider_api.RawBlockR\x08rawBlock2\xd3\x06\n\x10\x45ventProviderAPI\x12j\n\x0fGetLatestHeight\x12*.event_provider_api.GetLatestHeightRequest\x1a+.event_provider_api.GetLatestHeightResponse\x12u\n\x12StreamLatestHeight\x12-.event_provider_api.StreamLatestHeightRequest\x1a..event_provider_api.StreamLatestHeightResponse0\x01\x12r\n\x11StreamBlockEvents\x12,.event_provider_api.StreamBlockEventsRequest\x1a-.event_provider_api.StreamBlockEventsResponse0\x01\x12p\n\x11GetBlockEventsRPC\x12,.event_provider_api.GetBlockEventsRPCRequest\x1a-.event_provider_api.GetBlockEventsRPCResponse\x12s\n\x12GetCustomEventsRPC\x12-.event_provider_api.GetCustomEventsRPCRequest\x1a..event_provider_api.GetCustomEventsRPCResponse\x12s\n\x12GetABCIBlockEvents\x12-.event_provider_api.GetABCIBlockEventsRequest\x1a..event_provider_api.GetABCIBlockEventsResponse\x12\x8b\x01\n\x1aGetABCIBlockEventsAtHeight\x12\x35.event_provider_api.GetABCIBlockEventsAtHeightRequest\x1a\x36.event_provider_api.GetABCIBlockEventsAtHeightResponseB\xa6\x01\n\x16\x63om.event_provider_apiB\x15\x45ventProviderApiProtoP\x01Z\x15/event_provider_apipb\xa2\x02\x03\x45XX\xaa\x02\x10\x45ventProviderApi\xca\x02\x10\x45ventProviderApi\xe2\x02\x1c\x45ventProviderApi\\GPBMetadata\xea\x02\x10\x45ventProviderApib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.event_provider_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.event_provider_apiB\025EventProviderApiProtoP\001Z\025/event_provider_apipb\242\002\003EXX\252\002\020EventProviderApi\312\002\020EventProviderApi\342\002\034EventProviderApi\\GPBMetadata\352\002\020EventProviderApi'
  _globals['_BLOCKEVENTSRPC_TXHASHESENTRY']._loaded_options = None
  _globals['_BLOCKEVENTSRPC_TXHASHESENTRY']._serialized_options = b'8\001'
  _globals['_GETLATESTHEIGHTREQUEST']._serialized_start=57
  _globals['_GETLATESTHEIGHTREQUEST']._serialized_end=81
  _globals['_GETLATESTHEIGHTRESPONSE']._serialized_start=83
  _globals['_GETLATESTHEIGHTRESPONSE']._serialized_end=209
  _globals['_LATESTBLOCKHEIGHT']._serialized_start=211
  _globals['_LATESTBLOCKHEIGHT']._serialized_end=274
  _globals['_STREAMLATESTHEIGHTREQUEST']._serialized_start=276
  _globals['_STREAMLATESTHEIGHTREQUEST']._serialized_end=303
  _globals['_STREAMLATESTHEIGHTRESPONSE']._serialized_start=305
  _globals['_STREAMLATESTHEIGHTRESPONSE']._serialized_end=377
  _globals['_STREAMBLOCKEVENTSREQUEST']._serialized_start=379
  _globals['_STREAMBLOCKEVENTSREQUEST']._serialized_end=455
  _globals['_STREAMBLOCKEVENTSRESPONSE']._serialized_start=457
  _globals['_STREAMBLOCKEVENTSRESPONSE']._serialized_end=535
  _globals['_BLOCK']._serialized_start=538
  _globals['_BLOCK']._serialized_end=676
  _globals['_BLOCKEVENT']._serialized_start=678
  _globals['_BLOCKEVENT']._serialized_end=784
  _globals['_GETBLOCKEVENTSRPCREQUEST']._serialized_start=786
  _globals['_GETBLOCKEVENTSRPCREQUEST']._serialized_end=901
  _globals['_GETBLOCKEVENTSRPCRESPONSE']._serialized_start=904
  _globals['_GETBLOCKEVENTSRPCRESPONSE']._serialized_end=1087
  _globals['_BLOCKEVENTSRPC']._serialized_start=1090
  _globals['_BLOCKEVENTSRPC']._serialized_end=1292
  _globals['_BLOCKEVENTSRPC_TXHASHESENTRY']._serialized_start=1233
  _globals['_BLOCKEVENTSRPC_TXHASHESENTRY']._serialized_end=1292
  _globals['_BASICBLOCKINFO']._serialized_start=1294
  _globals['_BASICBLOCKINFO']._serialized_end=1384
  _globals['_GETCUSTOMEVENTSRPCREQUEST']._serialized_start=1386
  _globals['_GETCUSTOMEVENTSRPCREQUEST']._serialized_end=1487
  _globals['_GETCUSTOMEVENTSRPCRESPONSE']._serialized_start=1490
  _globals['_GETCUSTOMEVENTSRPCRESPONSE']._serialized_end=1674
  _globals['_GETABCIBLOCKEVENTSREQUEST']._serialized_start=1676
  _globals['_GETABCIBLOCKEVENTSREQUEST']._serialized_end=1760
  _globals['_GETABCIBLOCKEVENTSRESPONSE']._serialized_start=1763
  _globals['_GETABCIBLOCKEVENTSRESPONSE']._serialized_end=1892
  _globals['_RAWBLOCK']._serialized_start=1895
  _globals['_RAWBLOCK']._serialized_end=2227
  _globals['_ABCIRESPONSEDELIVERTX']._serialized_start=2230
  _globals['_ABCIRESPONSEDELIVERTX']._serialized_end=2479
  _globals['_ABCIEVENT']._serialized_start=2481
  _globals['_ABCIEVENT']._serialized_end=2579
  _globals['_ABCIATTRIBUTE']._serialized_start=2581
  _globals['_ABCIATTRIBUTE']._serialized_end=2636
  _globals['_GETABCIBLOCKEVENTSATHEIGHTREQUEST']._serialized_start=2638
  _globals['_GETABCIBLOCKEVENTSATHEIGHTREQUEST']._serialized_end=2697
  _globals['_GETABCIBLOCKEVENTSATHEIGHTRESPONSE']._serialized_start=2700
  _globals['_GETABCIBLOCKEVENTSATHEIGHTRESPONSE']._serialized_end=2837
  _globals['_EVENTPROVIDERAPI']._serialized_start=2840
  _globals['_EVENTPROVIDERAPI']._serialized_end=3691
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/nft/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/nft/v1beta1/tx.proto\x12\x12\x63osmos.nft.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\xa9\x01\n\x07MsgSend\x12\x19\n\x08\x63lass_id\x18\x01 \x01(\tR\x07\x63lassId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x30\n\x06sender\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x34\n\x08receiver\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08receiver:\x0b\x82\xe7\xb0*\x06sender\"\x11\n\x0fMsgSendResponse2V\n\x03Msg\x12H\n\x04Send\x12\x1b.cosmos.nft.v1beta1.MsgSend\x1a#.cosmos.nft.v1beta1.MsgSendResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x9f\x01\n\x16\x63om.cosmos.nft.v1beta1B\x07TxProtoP\x01Z\x12\x63osmossdk.io/x/nft\xa2\x02\x03\x43NX\xaa\x02\x12\x43osmos.Nft.V1beta1\xca\x02\x12\x43osmos\\Nft\\V1beta1\xe2\x02\x1e\x43osmos\\Nft\\V1beta1\\GPBMetadata\xea\x02\x14\x43osmos::Nft::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.cosmos.nft.v1beta1B\007TxProtoP\001Z\022cosmossdk.io/x/nft\242\002\003CNX\252\002\022Cosmos.Nft.V1beta1\312\002\022Cosmos\\Nft\\V1beta1\342\002\036Cosmos\\Nft\\V1beta1\\GPBMetadata\352\002\024Cosmos::Nft::V1beta1'
  _globals['_MSGSEND'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGSEND'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSEND'].fields_by_name['receiver']._loaded_options = None
  _globals['_MSGSEND'].fields_by_name['receiver']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSEND']._loaded_options = None
  _globals['_MSGSEND']._serialized_options = b'\202\347\260*\006sender'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSEND']._serialized_start=104
  _globals['_MSGSEND']._serialized_end=273
  _globals['_MSGSENDRESPONSE']._serialized_start=275
  _globals['_MSGSENDRESPONSE']._serialized_end=292
  _globals['_MSG']._serialized_start=294
  _globals['_MSG']._serialized_end=380
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/v1/account.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ibc/applications/interchain_accounts/v1/account.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\"\xcb\x01\n\x11InterchainAccount\x12I\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x04\xd0\xde\x1f\x01R\x0b\x62\x61seAccount\x12#\n\raccount_owner\x18\x02 \x01(\tR\x0c\x61\x63\x63ountOwner:F\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xca\xb4-:ibc.applications.interchain_accounts.v1.InterchainAccountIB\xbd\x02\n+com.ibc.applications.interchain_accounts.v1B\x0c\x41\x63\x63ountProtoP\x01ZEgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/types\xa2\x02\x03IAI\xaa\x02&Ibc.Applications.InterchainAccounts.V1\xca\x02&Ibc\\Applications\\InterchainAccounts\\V1\xe2\x02\x32Ibc\\Applications\\InterchainAccounts\\V1\\GPBMetadata\xea\x02)Ibc::Applications::InterchainAccounts::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.ibc.applications.interchain_accounts.v1B\014AccountProtoP\001ZEgithub.com/cosmos/ibc-go/v8/modules/apps/27-interchain-accounts/types\242\002\003IAI\252\002&Ibc.Applications.InterchainAccounts.V1\312\002&Ibc\\Applications\\InterchainAccounts\\V1\342\0022Ibc\\Applications\\InterchainAccounts\\V1\\GPBMetadata\352\002)Ibc::Applications::InterchainAccounts::V1'
  _globals['_INTERCHAINACCOUNT'].fields_by_name['base_account']._loaded_options = None
  _globals['_INTERCHAINACCOUNT'].fields_by_name['base_account']._serialized_options = b'\320\336\037\001'
  _globals['_INTERCHAINACCOUNT']._loaded_options = None
  _globals['_INTERCHAINACCOUNT']._serialized_options = b'\210\240\037\000\230\240\037\000\312\264-:ibc.applications.interchain_accounts.v1.InterchainAccountI'
  _globals['_INTERCHAINACCOUNT']._serialized_start=180
  _globals['_INTERCHAINACCOUNT']._serialized_end=383
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, List, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.exchange import (
    injective_spot_exchange_rpc_pb2 as exchange_spot_pb,
    injective_spot_exchange_rpc_pb2_grpc as exchange_spot_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IndexerGrpcSpotApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = self._stub = exchange_spot_grpc.InjectiveSpotExchangeRPCStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_markets(
        self,
        market_statuses: Optional[List[str]] = None,
        base_denom: Optional[str] = None,
        quote_denom: Optional[str] = None,
    ) -> Dict[str, Any]:
        request = exchange_spot_pb.MarketsRequest(
            market_statuses=market_statuses,
            base_denom=base_denom,
            quote_denom=quote_denom,
        )
        response = await self._execute_call(call=self._stub.Markets, request=request)

        return response

    async def fetch_market(self, market_id: str) -> Dict[str, Any]:
        request = exchange_spot_pb.MarketRequest(market_id=market_id)
        response = await self._execute_call(call=self._stub.Market, request=request)

        return response

    async def fetch_orderbook_v2(self, market_id: str, depth: int) -> Dict[str, Any]:
        request = exchange_spot_pb.OrderbookV2Request(market_id=market_id, depth=depth)
        response = await self._execute_call(call=self._stub.OrderbookV2, request=request)

        return response

    async def fetch_orderbooks_v2(self, market_ids: List[str], depth: int) -> Dict[str, Any]:
        request = exchange_spot_pb.OrderbooksV2Request(market_ids=market_ids, depth=depth)
        response = await self._execute_call(call=self._stub.OrderbooksV2, request=request)

        return response

    async def fetch_orders(
        self,
        market_ids: Optional[List[str]] = None,
        order_side: Optional[str] = None,
        subaccount_id: Optional[str] = None,
        include_inactive: Optional[bool] = None,
        subaccount_total_orders: Optional[bool] = None,
        trade_id: Optional[str] = None,
        cid: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.OrdersRequest(
            market_ids=market_ids,
            order_side=order_side,
            subaccount_id=subaccount_id,
            skip=pagination.skip,
            limit=pagination.limit,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            include_inactive=include_inactive,
            subaccount_total_orders=subaccount_total_orders,
            trade_id=trade_id,
            cid=cid,
        )

        response = await self._execute_call(call=self._stub.Orders, request=request)

        return response

    async def fetch_trades(
        self,
        market_ids: Optional[List[str]] = None,
        subaccount_ids: Optional[List[str]] = None,
        execution_side: Optional[str] = None,
        direction: Optional[str] = None,
        execution_types: Optional[List[str]] = None,
        trade_id: Optional[str] = None,
        account_address: Optional[str] = None,
        cid: Optional[str] = None,
        fee_recipient: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.TradesRequest(
            market_ids=market_ids,
            subaccount_ids=subaccount_ids,
            execution_side=execution_side,
            direction=direction,
            skip=pagination.skip,
            limit=pagination.limit,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            execution_types=execution_types,
            trade_id=trade_id,
            account_address=account_address,
            cid=cid,
            fee_recipient=fee_recipient,
        )

        response = await self._execute_call(call=self._stub.Trades, request=request)

        return response

    async def fetch_subaccount_orders_list(
        self,
        subaccount_id: str,
        market_id: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.SubaccountOrdersListRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
            skip=pagination.skip,
            limit=pagination.limit,
        )

        response = await self._execute_call(call=self._stub.SubaccountOrdersList, request=request)

        return response

    async def fetch_subaccount_trades_list(
        self,
        subaccount_id: str,
        market_id: Optional[str] = None,
        execution_type: Optional[str] = None,
        direction: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.SubaccountTradesListRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
            execution_type=execution_type,
            direction=direction,
            skip=pagination.skip,
            limit=pagination.limit,
        )

        response = await self._execute_call(call=self._stub.SubaccountTradesList, request=request)

        return response

    async def fetch_orders_history(
        self,
        subaccount_id: Optional[str] = None,
        market_ids: Optional[List[str]] = None,
        order_types: Optional[List[str]] = None,
        direction: Optional[str] = None,
        state: Optional[str] = None,
        execution_types: Optional[List[str]] = None,
        trade_id: Optional[str] = None,
        active_markets_only: Optional[bool] = None,
        cid: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.OrdersHistoryRequest(
            subaccount_id=subaccount_id,
            market_ids=market_ids,
            skip=pagination.skip,
            limit=pagination.limit,
            order_types=order_types,
            direction=direction,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            state=state,
            execution_types=execution_types,
            trade_id=trade_id,
            active_markets_only=active_markets_only,
            cid=cid,
        )

        response = await self._execute_call(call=self._stub.OrdersHistory, request=request)

        return response

    async def fetch_atomic_swap_history(
        self,
        address: str,
        contract_address: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.AtomicSwapHistoryRequest(
            address=address,
            contract_address=contract_address,
            skip=pagination.skip,
            limit=pagination.limit,
            from_number=pagination.from_number,
            to_number=pagination.to_number,
        )

        response = await self._execute_call(call=self._stub.AtomicSwapHistory, request=request)

        return response

    async def fetch_trades_v2(
        self,
        market_ids: Optional[List[str]] = None,
        subaccount_ids: Optional[List[str]] = None,
        execution_side: Optional[str] = None,
        direction: Optional[str] = None,
        execution_types: Optional[List[str]] = None,
        trade_id: Optional[str] = None,
        account_address: Optional[str] = None,
        cid: Optional[str] = None,
        fee_recipient: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.TradesV2Request(
            market_ids=market_ids,
            subaccount_ids=subaccount_ids,
            execution_side=execution_side,
            direction=direction,
            skip=pagination.skip,
            limit=pagination.limit,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            execution_types=execution_types,
            trade_id=trade_id,
            account_address=account_address,
            cid=cid,
            fee_recipient=fee_recipient,
        )

        response = await self._execute_call(call=self._stub.TradesV2, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.cosmos.base.tendermint.v1beta1 import (
    query_pb2 as tendermint_query,
    query_pb2_grpc as tendermint_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class TendermintGrpcApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = tendermint_query_grpc.ServiceStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_node_info(self) -> Dict[str, Any]:
        request = tendermint_query.GetNodeInfoRequest()
        response = await self._execute_call(call=self._stub.GetNodeInfo, request=request)

        return response

    async def fetch_syncing(self) -> Dict[str, Any]:
        request = tendermint_query.GetSyncingRequest()
        response = await self._execute_call(call=self._stub.GetSyncing, request=request)

        return response

    async def fetch_latest_block(self) -> Dict[str, Any]:
        request = tendermint_query.GetLatestBlockRequest()
        response = await self._execute_call(call=self._stub.GetLatestBlock, request=request)

        return response

    async def fetch_block_by_height(self, height: int) -> Dict[str, Any]:
        request = tendermint_query.GetBlockByHeightRequest(height=height)
        response = await self._execute_call(call=self._stub.GetBlockByHeight, request=request)

        return response

    async def fetch_latest_validator_set(self) -> Dict[str, Any]:
        request = tendermint_query.GetLatestValidatorSetRequest()
        response = await self._execute_call(call=self._stub.GetLatestValidatorSet, request=request)

        return response

    async def fetch_validator_set_by_height(
        self, height: int, pagination: Optional[PaginationOption] = None
    ) -> Dict[str, Any]:
        if pagination is None:
            pagination = PaginationOption()
        request = tendermint_query.GetValidatorSetByHeightRequest(
            height=height, pagination=pagination.create_pagination_request()
        )
        response = await self._execute_call(call=self._stub.GetValidatorSetByHeight, request=request)

        return response

    async def abci_query(
        self, path: str, data: Optional[bytes] = None, height: Optional[int] = None, prove: bool = False
    ) -> Dict[str, Any]:
        request = tendermint_query.ABCIQueryRequest(path=path, data=data, height=height, prove=prove)
        response = await self._execute_call(call=self._stub.ABCIQuery, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v2/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.exchange.v2 import exchange_pb2 as injective_dot_exchange_dot_v2_dot_exchange__pb2
from pyinjective.proto.injective.exchange.v2 import market_pb2 as injective_dot_exchange_dot_v2_dot_market__pb2
from pyinjective.proto.injective.exchange.v2 import orderbook_pb2 as injective_dot_exchange_dot_v2_dot_orderbook__pb2
from pyinjective.proto.injective.exchange.v2 import tx_pb2 as injective_dot_exchange_dot_v2_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/exchange/v2/genesis.proto\x12\x15injective.exchange.v2\x1a\x14gogoproto/gogo.proto\x1a$injective/exchange/v2/exchange.proto\x1a\"injective/exchange/v2/market.proto\x1a%injective/exchange/v2/orderbook.proto\x1a\x1einjective/exchange/v2/tx.proto\"\xec\x1c\n\x0cGenesisState\x12;\n\x06params\x18\x01 \x01(\x0b\x32\x1d.injective.exchange.v2.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12\x44\n\x0cspot_markets\x18\x02 \x03(\x0b\x32!.injective.exchange.v2.SpotMarketR\x0bspotMarkets\x12V\n\x12\x64\x65rivative_markets\x18\x03 \x03(\x0b\x32\'.injective.exchange.v2.DerivativeMarketR\x11\x64\x65rivativeMarkets\x12Q\n\x0espot_orderbook\x18\x04 \x03(\x0b\x32$.injective.exchange.v2.SpotOrderBookB\x04\xc8\xde\x1f\x00R\rspotOrderbook\x12\x63\n\x14\x64\x65rivative_orderbook\x18\x05 \x03(\x0b\x32*.injective.exchange.v2.DerivativeOrderBookB\x04\xc8\xde\x1f\x00R\x13\x64\x65rivativeOrderbook\x12@\n\x08\x62\x61lances\x18\x06 \x03(\x0b\x32\x1e.injective.exchange.v2.BalanceB\x04\xc8\xde\x1f\x00R\x08\x62\x61lances\x12M\n\tpositions\x18\x07 \x03(\x0b\x32).injective.exchange.v2.DerivativePositionB\x04\xc8\xde\x1f\x00R\tpositions\x12\x64\n\x17subaccount_trade_nonces\x18\x08 \x03(\x0b\x32&.injective.exchange.v2.SubaccountNonceB\x04\xc8\xde\x1f\x00R\x15subaccountTradeNonces\x12\x81\x01\n expiry_futures_market_info_state\x18\t \x03(\x0b\x32\x33.injective.exchange.v2.ExpiryFuturesMarketInfoStateB\x04\xc8\xde\x1f\x00R\x1c\x65xpiryFuturesMarketInfoState\x12\x64\n\x15perpetual_market_info\x18\n \x03(\x0b\x32*.injective.exchange.v2.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00R\x13perpetualMarketInfo\x12}\n\x1eperpetual_market_funding_state\x18\x0b \x03(\x0b\x32\x32.injective.exchange.v2.PerpetualMarketFundingStateB\x04\xc8\xde\x1f\x00R\x1bperpetualMarketFundingState\x12\x90\x01\n&derivative_market_settlement_scheduled\x18\x0c \x03(\x0b\x32\x35.injective.exchange.v2.DerivativeMarketSettlementInfoB\x04\xc8\xde\x1f\x00R#derivativeMarketSettlementScheduled\x12\x37\n\x18is_spot_exchange_enabled\x18\r \x01(\x08R\x15isSpotExchangeEnabled\x12\x45\n\x1fis_derivatives_exchange_enabled\x18\x0e \x01(\x08R\x1cisDerivativesExchangeEnabled\x12q\n\x1ctrading_reward_campaign_info\x18\x0f \x01(\x0b\x32\x30.injective.exchange.v2.TradingRewardCampaignInfoR\x19tradingRewardCampaignInfo\x12{\n%trading_reward_pool_campaign_schedule\x18\x10 \x03(\x0b\x32).injective.exchange.v2.CampaignRewardPoolR!tradingRewardPoolCampaignSchedule\x12\x8d\x01\n&trading_reward_campaign_account_points\x18\x11 \x03(\x0b\x32\x39.injective.exchange.v2.TradingRewardCampaignAccountPointsR\"tradingRewardCampaignAccountPoints\x12^\n\x15\x66\x65\x65_discount_schedule\x18\x12 \x01(\x0b\x32*.injective.exchange.v2.FeeDiscountScheduleR\x13\x66\x65\x65\x44iscountSchedule\x12r\n\x1d\x66\x65\x65_discount_account_tier_ttl\x18\x13 \x03(\x0b\x32\x30.injective.exchange.v2.FeeDiscountAccountTierTTLR\x19\x66\x65\x65\x44iscountAccountTierTtl\x12\x84\x01\n#fee_discount_bucket_volume_accounts\x18\x14 \x03(\x0b\x32\x36.injective.exchange.v2.FeeDiscountBucketVolumeAccountsR\x1f\x66\x65\x65\x44iscountBucketVolumeAccounts\x12<\n\x1bis_first_fee_cycle_finished\x18\x15 \x01(\x08R\x17isFirstFeeCycleFinished\x12\x8a\x01\n-pending_trading_reward_pool_campaign_schedule\x18\x16 \x03(\x0b\x32).injective.exchange.v2.CampaignRewardPoolR(pendingTradingRewardPoolCampaignSchedule\x12\xa3\x01\n.pending_trading_reward_campaign_account_points\x18\x17 \x03(\x0b\x32@.injective.exchange.v2.TradingRewardCampaignAccountPendingPointsR)pendingTradingRewardCampaignAccountPoints\x12\x39\n\x19rewards_opt_out_addresses\x18\x18 \x03(\tR\x16rewardsOptOutAddresses\x12]\n\x18historical_trade_records\x18\x19 \x03(\x0b\x32#.injective.exchange.v2.TradeRecordsR\x16historicalTradeRecords\x12`\n\x16\x62inary_options_markets\x18\x1a \x03(\x0b\x32*.injective.exchange.v2.BinaryOptionsMarketR\x14\x62inaryOptionsMarkets\x12h\n2binary_options_market_ids_scheduled_for_settlement\x18\x1b \x03(\tR,binaryOptionsMarketIdsScheduledForSettlement\x12T\n(spot_market_ids_scheduled_to_force_close\x18\x1c \x03(\tR\"spotMarketIdsScheduledToForceClose\x12Q\n\x0e\x64\x65nom_decimals\x18\x1d \x03(\x0b\x32$.injective.exchange.v2.DenomDecimalsB\x04\xc8\xde\x1f\x00R\rdenomDecimals\x12\x81\x01\n!conditional_derivative_orderbooks\x18\x1e \x03(\x0b\x32\x35.injective.exchange.v2.ConditionalDerivativeOrderBookR\x1f\x63onditionalDerivativeOrderbooks\x12`\n\x16market_fee_multipliers\x18\x1f \x03(\x0b\x32*.injective.exchange.v2.MarketFeeMultiplierR\x14marketFeeMultipliers\x12Y\n\x13orderbook_sequences\x18  \x03(\x0b\x32(.injective.exchange.v2.OrderbookSequenceR\x12orderbookSequences\x12\x65\n\x12subaccount_volumes\x18! \x03(\x0b\x32\x36.injective.exchange.v2.AggregateSubaccountVolumeRecordR\x11subaccountVolumes\x12J\n\x0emarket_volumes\x18\" \x03(\x0b\x32#.injective.exchange.v2.MarketVolumeR\rmarketVolumes\x12\x61\n\x14grant_authorizations\x18# \x03(\x0b\x32..injective.exchange.v2.FullGrantAuthorizationsR\x13grantAuthorizations\x12K\n\ractive_grants\x18$ \x03(\x0b\x32&.injective.exchange.v2.FullActiveGrantR\x0c\x61\x63tiveGrants\x12W\n\x13\x64\x65nom_min_notionals\x18% \x03(\x0b\x32\'.injective.exchange.v2.DenomMinNotionalR\x11\x64\x65nomMinNotionals\"L\n\x11OrderbookSequence\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"{\n\x19\x46\x65\x65\x44iscountAccountTierTTL\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x44\n\x08tier_ttl\x18\x02 \x01(\x0b\x32).injective.exchange.v2.FeeDiscountTierTTLR\x07tierTtl\"\xa4\x01\n\x1f\x46\x65\x65\x44iscountBucketVolumeAccounts\x12\x34\n\x16\x62ucket_start_timestamp\x18\x01 \x01(\x03R\x14\x62ucketStartTimestamp\x12K\n\x0e\x61\x63\x63ount_volume\x18\x02 \x03(\x0b\x32$.injective.exchange.v2.AccountVolumeR\raccountVolume\"f\n\rAccountVolume\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12;\n\x06volume\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06volume\"{\n\"TradingRewardCampaignAccountPoints\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12;\n\x06points\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06points\"\xcc\x01\n)TradingRewardCampaignAccountPendingPoints\x12=\n\x1breward_pool_start_timestamp\x18\x01 \x01(\x03R\x18rewardPoolStartTimestamp\x12`\n\x0e\x61\x63\x63ount_points\x18\x02 \x03(\x0b\x32\x39.injective.exchange.v2.TradingRewardCampaignAccountPointsR\raccountPoints\"\xa9\x01\n\x0fSubaccountNonce\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12g\n\x16subaccount_trade_nonce\x18\x02 \x01(\x0b\x32+.injective.exchange.v2.SubaccountTradeNonceB\x04\xc8\xde\x1f\x00R\x14subaccountTradeNonce:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x86\x02\n\x17\x46ullGrantAuthorizations\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\x12K\n\x12total_grant_amount\x18\x02 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x10totalGrantAmount\x12\x41\n\x1dlast_delegations_checked_time\x18\x03 \x01(\x03R\x1alastDelegationsCheckedTime\x12\x41\n\x06grants\x18\x04 \x03(\x0b\x32).injective.exchange.v2.GrantAuthorizationR\x06grants\"r\n\x0f\x46ullActiveGrant\x12\x18\n\x07grantee\x18\x01 \x01(\tR\x07grantee\x12\x45\n\x0c\x61\x63tive_grant\x18\x02 \x01(\x0b\x32\".injective.exchange.v2.ActiveGrantR\x0b\x61\x63tiveGrantB\xf2\x01\n\x19\x63om.injective.exchange.v2B\x0cGenesisProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\xa2\x02\x03IEX\xaa\x02\x15Injective.Exchange.V2\xca\x02\x15Injective\\Exchange\\V2\xe2\x02!Injective\\Exchange\\V2\\GPBMetadata\xea\x02\x17Injective::Exchange::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v2.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.exchange.v2B\014GenesisProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\242\002\003IEX\252\002\025Injective.Exchange.V2\312\002\025Injective\\Exchange\\V2\342\002!Injective\\Exchange\\V2\\GPBMetadata\352\002\027Injective::Exchange::V2'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['spot_orderbook']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['spot_orderbook']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['derivative_orderbook']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['derivative_orderbook']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['balances']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['positions']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['positions']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['subaccount_trade_nonces']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['subaccount_trade_nonces']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['expiry_futures_market_info_state']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['expiry_futures_market_info_state']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['perpetual_market_info']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['perpetual_market_info']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['perpetual_market_funding_state']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['perpetual_market_funding_state']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['derivative_market_settlement_scheduled']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['derivative_market_settlement_scheduled']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['denom_decimals']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['denom_decimals']._serialized_options = b'\310\336\037\000'
  _globals['_ACCOUNTVOLUME'].fields_by_name['volume']._loaded_options = None
  _globals['_ACCOUNTVOLUME'].fields_by_name['volume']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRADINGREWARDCAMPAIGNACCOUNTPOINTS'].fields_by_name['points']._loaded_options = None
  _globals['_TRADINGREWARDCAMPAIGNACCOUNTPOINTS'].fields_by_name['points']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SUBACCOUNTNONCE'].fields_by_name['subaccount_trade_nonce']._loaded_options = None
  _globals['_SUBACCOUNTNONCE'].fields_by_name['subaccount_trade_nonce']._serialized_options = b'\310\336\037\000'
  _globals['_SUBACCOUNTNONCE']._loaded_options = None
  _globals['_SUBACCOUNTNONCE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_FULLGRANTAUTHORIZATIONS'].fields_by_name['total_grant_amount']._loaded_options = None
  _globals['_FULLGRANTAUTHORIZATIONS'].fields_by_name['total_grant_amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_GENESISSTATE']._serialized_start=230
  _globals['_GENESISSTATE']._serialized_end=3922
  _globals['_ORDERBOOKSEQUENCE']._serialized_start=3924
  _globals['_ORDERBOOKSEQUENCE']._serialized_end=4000
  _globals['_FEEDISCOUNTACCOUNTTIERTTL']._serialized_start=4002
  _globals['_FEEDISCOUNTACCOUNTTIERTTL']._serialized_end=4125
  _globals['_FEEDISCOUNTBUCKETVOLUMEACCOUNTS']._serialized_start=4128
  _globals['_FEEDISCOUNTBUCKETVOLUMEACCOUNTS']._serialized_end=4292
  _globals['_ACCOUNTVOLUME']._serialized_start=4294
  _globals['_ACCOUNTVOLUME']._serialized_end=4396
  _globals['_TRADINGREWARDCAMPAIGNACCOUNTPOINTS']._serialized_start=4398
  _globals['_TRADINGREWARDCAMPAIGNACCOUNTPOINTS']._serialized_end=4521
  _globals['_TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS']._serialized_start=4524
  _globals['_TRADINGREWARDCAMPAIGNACCOUNTPENDINGPOINTS']._serialized_end=4728
  _globals['_SUBACCOUNTNONCE']._serialized_start=4731
  _globals['_SUBACCOUNTNONCE']._serialized_end=4900
  _globals['_FULLGRANTAUTHORIZATIONS']._serialized_start=4903
  _globals['_FULLGRANTAUTHORIZATIONS']._serialized_end=5165
  _globals['_FULLACTIVEGRANT']._serialized_start=5167
  _globals['_FULLACTIVEGRANT']._serialized_end=5281
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/oracle/v1beta1/tx.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xda\x01\n\x16MsgRelayProviderPrices\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x18\n\x07symbols\x18\x03 \x03(\tR\x07symbols\x12;\n\x06prices\x18\x04 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06prices:5\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1doracle/MsgRelayProviderPrices\" \n\x1eMsgRelayProviderPricesResponse\"\xcc\x01\n\x16MsgRelayPriceFeedPrice\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x12\n\x04\x62\x61se\x18\x02 \x03(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x03 \x03(\tR\x05quote\x12\x39\n\x05price\x18\x04 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price:5\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1doracle/MsgRelayPriceFeedPrice\" \n\x1eMsgRelayPriceFeedPriceResponse\"\xcd\x01\n\x11MsgRelayBandRates\x12\x18\n\x07relayer\x18\x01 \x01(\tR\x07relayer\x12\x18\n\x07symbols\x18\x02 \x03(\tR\x07symbols\x12\x14\n\x05rates\x18\x03 \x03(\x04R\x05rates\x12#\n\rresolve_times\x18\x04 \x03(\x04R\x0cresolveTimes\x12\x1e\n\nrequestIDs\x18\x05 \x03(\x04R\nrequestIDs:)\x82\xe7\xb0*\x07relayer\x8a\xe7\xb0*\x18oracle/MsgRelayBandRates\"\x1b\n\x19MsgRelayBandRatesResponse\"\xa7\x01\n\x18MsgRelayCoinbaseMessages\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08messages\x18\x02 \x03(\x0cR\x08messages\x12\x1e\n\nsignatures\x18\x03 \x03(\x0cR\nsignatures:7\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1foracle/MsgRelayCoinbaseMessages\"\"\n MsgRelayCoinbaseMessagesResponse\"\x88\x01\n\x13MsgRelayStorkPrices\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x44\n\x0b\x61sset_pairs\x18\x02 \x03(\x0b\x32#.injective.oracle.v1beta1.AssetPairR\nassetPairs:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x1d\n\x1bMsgRelayStorkPricesResponse\"\x86\x01\n\x16MsgRequestBandIBCRates\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1d\n\nrequest_id\x18\x02 \x01(\x04R\trequestId:5\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1doracle/MsgRequestBandIBCRates\" \n\x1eMsgRequestBandIBCRatesResponse\"\xba\x01\n\x12MsgRelayPythPrices\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12Y\n\x12price_attestations\x18\x02 \x03(\x0b\x32*.injective.oracle.v1beta1.PriceAttestationR\x11priceAttestations:1\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x19oracle/MsgRelayPythPrices\"\x1c\n\x1aMsgRelayPythPricesResponse\"\xb4\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12>\n\x06params\x18\x02 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:)\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x16oracle/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\xf6\x07\n\x03Msg\x12\x81\x01\n\x13RelayProviderPrices\x12\x30.injective.oracle.v1beta1.MsgRelayProviderPrices\x1a\x38.injective.oracle.v1beta1.MsgRelayProviderPricesResponse\x12\x81\x01\n\x13RelayPriceFeedPrice\x12\x30.injective.oracle.v1beta1.MsgRelayPriceFeedPrice\x1a\x38.injective.oracle.v1beta1.MsgRelayPriceFeedPriceResponse\x12r\n\x0eRelayBandRates\x12+.injective.oracle.v1beta1.MsgRelayBandRates\x1a\x33.injective.oracle.v1beta1.MsgRelayBandRatesResponse\x12\x81\x01\n\x13RequestBandIBCRates\x12\x30.injective.oracle.v1beta1.MsgRequestBandIBCRates\x1a\x38.injective.oracle.v1beta1.MsgRequestBandIBCRatesResponse\x12\x87\x01\n\x15RelayCoinbaseMessages\x12\x32.injective.oracle.v1beta1.MsgRelayCoinbaseMessages\x1a:.injective.oracle.v1beta1.MsgRelayCoinbaseMessagesResponse\x12y\n\x11RelayStorkMessage\x12-.injective.oracle.v1beta1.MsgRelayStorkPrices\x1a\x35.injective.oracle.v1beta1.MsgRelayStorkPricesResponse\x12u\n\x0fRelayPythPrices\x12,.injective.oracle.v1beta1.MsgRelayPythPrices\x1a\x34.injective.oracle.v1beta1.MsgRelayPythPricesResponse\x12l\n\x0cUpdateParams\x12).injective.oracle.v1beta1.MsgUpdateParams\x1a\x31.injective.oracle.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xf7\x01\n\x1c\x63om.injective.oracle.v1beta1B\x07TxProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\007TxProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_MSGRELAYPROVIDERPRICES'].fields_by_name['prices']._loaded_options = None
  _globals['_MSGRELAYPROVIDERPRICES'].fields_by_name['prices']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGRELAYPROVIDERPRICES']._loaded_options = None
  _globals['_MSGRELAYPROVIDERPRICES']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\035oracle/MsgRelayProviderPrices'
  _globals['_MSGRELAYPRICEFEEDPRICE'].fields_by_name['price']._loaded_options = None
  _globals['_MSGRELAYPRICEFEEDPRICE'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_MSGRELAYPRICEFEEDPRICE']._loaded_options = None
  _globals['_MSGRELAYPRICEFEEDPRICE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\035oracle/MsgRelayPriceFeedPrice'
  _globals['_MSGRELAYBANDRATES']._loaded_options = None
  _globals['_MSGRELAYBANDRATES']._serialized_options = b'\202\347\260*\007relayer\212\347\260*\030oracle/MsgRelayBandRates'
  _globals['_MSGRELAYCOINBASEMESSAGES']._loaded_options = None
  _globals['_MSGRELAYCOINBASEMESSAGES']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\037oracle/MsgRelayCoinbaseMessages'
  _globals['_MSGRELAYSTORKPRICES']._loaded_options = None
  _globals['_MSGRELAYSTORKPRICES']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _globals['_MSGREQUESTBANDIBCRATES']._loaded_options = None
  _globals['_MSGREQUESTBANDIBCRATES']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\035oracle/MsgRequestBandIBCRates'
  _globals['_MSGRELAYPYTHPRICES']._loaded_options = None
  _globals['_MSGRELAYPYTHPRICES']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender\212\347\260*\031oracle/MsgRelayPythPrices'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\026oracle/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGRELAYPROVIDERPRICES']._serialized_start=196
  _globals['_MSGRELAYPROVIDERPRICES']._serialized_end=414
  _globals['_MSGRELAYPROVIDERPRICESRESPONSE']._serialized_start=416
  _globals['_MSGRELAYPROVIDERPRICESRESPONSE']._serialized_end=448
  _globals['_MSGRELAYPRICEFEEDPRICE']._serialized_start=451
  _globals['_MSGRELAYPRICEFEEDPRICE']._serialized_end=655
  _globals['_MSGRELAYPRICEFEEDPRICERESPONSE']._serialized_start=657
  _globals['_MSGRELAYPRICEFEEDPRICERESPONSE']._serialized_end=689
  _globals['_MSGRELAYBANDRATES']._serialized_start=692
  _globals['_MSGRELAYBANDRATES']._serialized_end=897
  _globals['_MSGRELAYBANDRATESRESPONSE']._serialized_start=899
  _globals['_MSGRELAYBANDRATESRESPONSE']._serialized_end=926
  _globals['_MSGRELAYCOINBASEMESSAGES']._serialized_start=929
  _globals['_MSGRELAYCOINBASEMESSAGES']._serialized_end=1096
  _globals['_MSGRELAYCOINBASEMESSAGESRESPONSE']._serialized_start=1098
  _globals['_MSGRELAYCOINBASEMESSAGESRESPONSE']._serialized_end=1132
  _globals['_MSGRELAYSTORKPRICES']._serialized_start=1135
  _globals['_MSGRELAYSTORKPRICES']._serialized_end=1271
  _globals['_MSGRELAYSTORKPRICESRESPONSE']._serialized_start=1273
  _globals['_MSGRELAYSTORKPRICESRESPONSE']._serialized_end=1302
  _globals['_MSGREQUESTBANDIBCRATES']._serialized_start=1305
  _globals['_MSGREQUESTBANDIBCRATES']._serialized_end=1439
  _globals['_MSGREQUESTBANDIBCRATESRESPONSE']._serialized_start=1441
  _globals['_MSGREQUESTBANDIBCRATESRESPONSE']._serialized_end=1473
  _globals['_MSGRELAYPYTHPRICES']._serialized_start=1476
  _globals['_MSGRELAYPYTHPRICES']._serialized_end=1662
  _globals['_MSGRELAYPYTHPRICESRESPONSE']._serialized_start=1664
  _globals['_MSGRELAYPYTHPRICESRESPONSE']._serialized_end=1692
  _globals['_MSGUPDATEPARAMS']._serialized_start=1695
  _globals['_MSGUPDATEPARAMS']._serialized_end=1875
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1877
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1902
  _globals['_MSG']._serialized_start=1905
  _globals['_MSG']._serialized_end=2919
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/statesync/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/statesync/v1/types.proto\x12\x15\x63ometbft.statesync.v1\"\xde\x02\n\x07Message\x12V\n\x11snapshots_request\x18\x01 \x01(\x0b\x32\'.cometbft.statesync.v1.SnapshotsRequestH\x00R\x10snapshotsRequest\x12Y\n\x12snapshots_response\x18\x02 \x01(\x0b\x32(.cometbft.statesync.v1.SnapshotsResponseH\x00R\x11snapshotsResponse\x12J\n\rchunk_request\x18\x03 \x01(\x0b\x32#.cometbft.statesync.v1.ChunkRequestH\x00R\x0c\x63hunkRequest\x12M\n\x0e\x63hunk_response\x18\x04 \x01(\x0b\x32$.cometbft.statesync.v1.ChunkResponseH\x00R\rchunkResponseB\x05\n\x03sum\"\x12\n\x10SnapshotsRequest\"\x8b\x01\n\x11SnapshotsResponse\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x16\n\x06\x66ormat\x18\x02 \x01(\rR\x06\x66ormat\x12\x16\n\x06\x63hunks\x18\x03 \x01(\rR\x06\x63hunks\x12\x12\n\x04hash\x18\x04 \x01(\x0cR\x04hash\x12\x1a\n\x08metadata\x18\x05 \x01(\x0cR\x08metadata\"T\n\x0c\x43hunkRequest\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x16\n\x06\x66ormat\x18\x02 \x01(\rR\x06\x66ormat\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\"\x85\x01\n\rChunkResponse\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\x12\x16\n\x06\x66ormat\x18\x02 \x01(\rR\x06\x66ormat\x12\x14\n\x05index\x18\x03 \x01(\rR\x05index\x12\x14\n\x05\x63hunk\x18\x04 \x01(\x0cR\x05\x63hunk\x12\x18\n\x07missing\x18\x05 \x01(\x08R\x07missingB\xd5\x01\n\x19\x63om.cometbft.statesync.v1B\nTypesProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/statesync/v1\xa2\x02\x03\x43SX\xaa\x02\x15\x43ometbft.Statesync.V1\xca\x02\x15\x43ometbft\\Statesync\\V1\xe2\x02!Cometbft\\Statesync\\V1\\GPBMetadata\xea\x02\x17\x43ometbft::Statesync::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.statesync.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.statesync.v1B\nTypesProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/statesync/v1\242\002\003CSX\252\002\025Cometbft.Statesync.V1\312\002\025Cometbft\\Statesync\\V1\342\002!Cometbft\\Statesync\\V1\\GPBMetadata\352\002\027Cometbft::Statesync::V1'
  _globals['_MESSAGE']._serialized_start=61
  _globals['_MESSAGE']._serialized_end=411
  _globals['_SNAPSHOTSREQUEST']._serialized_start=413
  _globals['_SNAPSHOTSREQUEST']._serialized_end=431
  _globals['_SNAPSHOTSRESPONSE']._serialized_start=434
  _globals['_SNAPSHOTSRESPONSE']._serialized_end=573
  _globals['_CHUNKREQUEST']._serialized_start=575
  _globals['_CHUNKREQUEST']._serialized_end=659
  _globals['_CHUNKRESPONSE']._serialized_start=662
  _globals['_CHUNKRESPONSE']._serialized_end=795
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/authz.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/staking/v1beta1/authz.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\"\xfa\x04\n\x12StakeAuthorization\x12\x65\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB+\xaa\xdf\x1f\'github.com/cosmos/cosmos-sdk/types.CoinR\tmaxTokens\x12\x84\x01\n\nallow_list\x18\x02 \x01(\x0b\x32\x35.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsB,\xb2\xe7\xb0*\'cosmos-sdk/StakeAuthorization/AllowListH\x00R\tallowList\x12\x81\x01\n\tdeny_list\x18\x03 \x01(\x0b\x32\x35.cosmos.staking.v1beta1.StakeAuthorization.ValidatorsB+\xb2\xe7\xb0*&cosmos-sdk/StakeAuthorization/DenyListH\x00R\x08\x64\x65nyList\x12X\n\x12\x61uthorization_type\x18\x04 \x01(\x0e\x32).cosmos.staking.v1beta1.AuthorizationTypeR\x11\x61uthorizationType\x1a@\n\nValidators\x12\x32\n\x07\x61\x64\x64ress\x18\x01 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07\x61\x64\x64ress:H\xca\xb4-\"cosmos.authz.v1beta1.Authorization\x8a\xe7\xb0*\x1d\x63osmos-sdk/StakeAuthorizationB\x0c\n\nvalidators*\xd2\x01\n\x11\x41uthorizationType\x12\"\n\x1e\x41UTHORIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41UTHORIZATION_TYPE_DELEGATE\x10\x01\x12!\n\x1d\x41UTHORIZATION_TYPE_UNDELEGATE\x10\x02\x12!\n\x1d\x41UTHORIZATION_TYPE_REDELEGATE\x10\x03\x12\x32\n.AUTHORIZATION_TYPE_CANCEL_UNBONDING_DELEGATION\x10\x04\x42\xd0\x01\n\x1a\x63om.cosmos.staking.v1beta1B\nAuthzProtoP\x01Z,github.com/cosmos/cosmos-sdk/x/staking/types\xa2\x02\x03\x43SX\xaa\x02\x16\x43osmos.Staking.V1beta1\xca\x02\x16\x43osmos\\Staking\\V1beta1\xe2\x02\"Cosmos\\Staking\\V1beta1\\GPBMetadata\xea\x02\x18\x43osmos::Staking::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cosmos.staking.v1beta1B\nAuthzProtoP\001Z,github.com/cosmos/cosmos-sdk/x/staking/types\242\002\003CSX\252\002\026Cosmos.Staking.V1beta1\312\002\026Cosmos\\Staking\\V1beta1\342\002\"Cosmos\\Staking\\V1beta1\\GPBMetadata\352\002\030Cosmos::Staking::V1beta1'
  _globals['_STAKEAUTHORIZATION_VALIDATORS'].fields_by_name['address']._loaded_options = None
  _globals['_STAKEAUTHORIZATION_VALIDATORS'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_STAKEAUTHORIZATION'].fields_by_name['max_tokens']._loaded_options = None
  _globals['_STAKEAUTHORIZATION'].fields_by_name['max_tokens']._serialized_options = b'\252\337\037\'github.com/cosmos/cosmos-sdk/types.Coin'
  _globals['_STAKEAUTHORIZATION'].fields_by_name['allow_list']._loaded_options = None
  _globals['_STAKEAUTHORIZATION'].fields_by_name['allow_list']._serialized_options = b'\262\347\260*\'cosmos-sdk/StakeAuthorization/AllowList'
  _globals['_STAKEAUTHORIZATION'].fields_by_name['deny_list']._loaded_options = None
  _globals['_STAKEAUTHORIZATION'].fields_by_name['deny_list']._serialized_options = b'\262\347\260*&cosmos-sdk/StakeAuthorization/DenyList'
  _globals['_STAKEAUTHORIZATION']._loaded_options = None
  _globals['_STAKEAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization\212\347\260*\035cosmos-sdk/StakeAuthorization'
  _globals['_AUTHORIZATIONTYPE']._serialized_start=800
  _globals['_AUTHORIZATIONTYPE']._serialized_end=1010
  _globals['_STAKEAUTHORIZATION']._serialized_start=163
  _globals['_STAKEAUTHORIZATION']._serialized_end=797
  _globals['_STAKEAUTHORIZATION_VALIDATORS']._serialized_start=645
  _globals['_STAKEAUTHORIZATION_VALIDATORS']._serialized_end=709
# @@protoc_insertion_point(module_scope)



from typing import Callable, List, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.exchange import (
    injective_spot_exchange_rpc_pb2 as exchange_spot_pb,
    injective_spot_exchange_rpc_pb2_grpc as exchange_spot_grpc,
)
from pyinjective.utils.grpc_api_stream_assistant import GrpcApiStreamAssistant


class IndexerGrpcSpotStream:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = self._stub = exchange_spot_grpc.InjectiveSpotExchangeRPCStub(channel)
        self._assistant = GrpcApiStreamAssistant(cookie_assistant=cookie_assistant)

    async def stream_markets(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        market_ids: Optional[List[str]] = None,
    ):
        request = exchange_spot_pb.StreamMarketsRequest(
            market_ids=market_ids,
        )

        await self._assistant.listen_stream(
            call=self._stub.StreamMarkets,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_orderbook_v2(
        self,
        market_ids: List[str],
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
    ):
        request = exchange_spot_pb.StreamOrderbookV2Request(market_ids=market_ids)

        await self._assistant.listen_stream(
            call=self._stub.StreamOrderbookV2,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_orderbook_update(
        self,
        market_ids: List[str],
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
    ):
        request = exchange_spot_pb.StreamOrderbookUpdateRequest(market_ids=market_ids)

        await self._assistant.listen_stream(
            call=self._stub.StreamOrderbookUpdate,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_orders(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        market_ids: Optional[List[str]] = None,
        order_side: Optional[str] = None,
        subaccount_id: Optional[PaginationOption] = None,
        include_inactive: Optional[bool] = None,
        subaccount_total_orders: Optional[bool] = None,
        trade_id: Optional[str] = None,
        cid: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ):
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.StreamOrdersRequest(
            market_ids=market_ids,
            order_side=order_side,
            subaccount_id=subaccount_id,
            skip=pagination.skip,
            limit=pagination.limit,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            include_inactive=include_inactive,
            subaccount_total_orders=subaccount_total_orders,
            trade_id=trade_id,
            cid=cid,
        )

        await self._assistant.listen_stream(
            call=self._stub.StreamOrders,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_trades(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        market_ids: Optional[List[str]] = None,
        subaccount_ids: Optional[List[str]] = None,
        execution_side: Optional[str] = None,
        direction: Optional[str] = None,
        execution_types: Optional[List[str]] = None,
        trade_id: Optional[str] = None,
        account_address: Optional[str] = None,
        cid: Optional[str] = None,
        fee_recipient: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ):
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.StreamTradesRequest(
            execution_side=execution_side,
            direction=direction,
            skip=pagination.skip,
            limit=pagination.limit,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            market_ids=market_ids,
            subaccount_ids=subaccount_ids,
            execution_types=execution_types,
            trade_id=trade_id,
            account_address=account_address,
            cid=cid,
            fee_recipient=fee_recipient,
        )

        await self._assistant.listen_stream(
            call=self._stub.StreamTrades,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_orders_history(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        subaccount_id: Optional[str] = None,
        market_id: Optional[str] = None,
        order_types: Optional[List[str]] = None,
        direction: Optional[str] = None,
        state: Optional[str] = None,
        execution_types: Optional[List[str]] = None,
    ):
        request = exchange_spot_pb.StreamOrdersHistoryRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
            order_types=order_types,
            direction=direction,
            state=state,
            execution_types=execution_types,
        )

        await self._assistant.listen_stream(
            call=self._stub.StreamOrdersHistory,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )

    async def stream_trades_v2(
        self,
        callback: Callable,
        on_end_callback: Optional[Callable] = None,
        on_status_callback: Optional[Callable] = None,
        market_ids: Optional[List[str]] = None,
        subaccount_ids: Optional[List[str]] = None,
        execution_side: Optional[str] = None,
        direction: Optional[str] = None,
        execution_types: Optional[List[str]] = None,
        trade_id: Optional[str] = None,
        account_address: Optional[str] = None,
        cid: Optional[str] = None,
        fee_recipient: Optional[str] = None,
        pagination: Optional[PaginationOption] = None,
    ):
        pagination = pagination or PaginationOption()
        request = exchange_spot_pb.StreamTradesV2Request(
            execution_side=execution_side,
            direction=direction,
            skip=pagination.skip,
            limit=pagination.limit,
            start_time=pagination.start_time,
            end_time=pagination.end_time,
            market_ids=market_ids,
            subaccount_ids=subaccount_ids,
            execution_types=execution_types,
            trade_id=trade_id,
            account_address=account_address,
            cid=cid,
            fee_recipient=fee_recipient,
        )

        await self._assistant.listen_stream(
            call=self._stub.StreamTradesV2,
            request=request,
            callback=callback,
            on_end_callback=on_end_callback,
            on_status_callback=on_status_callback,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/wasm/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/lightclients/wasm/v1/tx.proto\x12\x18ibc.lightclients.wasm.v1\x1a\x17\x63osmos/msg/v1/msg.proto\"Y\n\x0cMsgStoreCode\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12$\n\x0ewasm_byte_code\x18\x02 \x01(\x0cR\x0cwasmByteCode:\x0b\x82\xe7\xb0*\x06signer\"2\n\x14MsgStoreCodeResponse\x12\x1a\n\x08\x63hecksum\x18\x01 \x01(\x0cR\x08\x63hecksum\"T\n\x11MsgRemoveChecksum\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12\x1a\n\x08\x63hecksum\x18\x02 \x01(\x0cR\x08\x63hecksum:\x0b\x82\xe7\xb0*\x06signer\"\x1b\n\x19MsgRemoveChecksumResponse\"\x84\x01\n\x12MsgMigrateContract\x12\x16\n\x06signer\x18\x01 \x01(\tR\x06signer\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\x12\x1a\n\x08\x63hecksum\x18\x03 \x01(\x0cR\x08\x63hecksum\x12\x10\n\x03msg\x18\x04 \x01(\x0cR\x03msg:\x0b\x82\xe7\xb0*\x06signer\"\x1c\n\x1aMsgMigrateContractResponse2\xdc\x02\n\x03Msg\x12\x63\n\tStoreCode\x12&.ibc.lightclients.wasm.v1.MsgStoreCode\x1a..ibc.lightclients.wasm.v1.MsgStoreCodeResponse\x12r\n\x0eRemoveChecksum\x12+.ibc.lightclients.wasm.v1.MsgRemoveChecksum\x1a\x33.ibc.lightclients.wasm.v1.MsgRemoveChecksumResponse\x12u\n\x0fMigrateContract\x12,.ibc.lightclients.wasm.v1.MsgMigrateContract\x1a\x34.ibc.lightclients.wasm.v1.MsgMigrateContractResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xe8\x01\n\x1c\x63om.ibc.lightclients.wasm.v1B\x07TxProtoP\x01Z<github.com/cosmos/ibc-go/modules/light-clients/08-wasm/types\xa2\x02\x03ILW\xaa\x02\x18Ibc.Lightclients.Wasm.V1\xca\x02\x18Ibc\\Lightclients\\Wasm\\V1\xe2\x02$Ibc\\Lightclients\\Wasm\\V1\\GPBMetadata\xea\x02\x1bIbc::Lightclients::Wasm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.wasm.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ibc.lightclients.wasm.v1B\007TxProtoP\001Z<github.com/cosmos/ibc-go/modules/light-clients/08-wasm/types\242\002\003ILW\252\002\030Ibc.Lightclients.Wasm.V1\312\002\030Ibc\\Lightclients\\Wasm\\V1\342\002$Ibc\\Lightclients\\Wasm\\V1\\GPBMetadata\352\002\033Ibc::Lightclients::Wasm::V1'
  _globals['_MSGSTORECODE']._loaded_options = None
  _globals['_MSGSTORECODE']._serialized_options = b'\202\347\260*\006signer'
  _globals['_MSGREMOVECHECKSUM']._loaded_options = None
  _globals['_MSGREMOVECHECKSUM']._serialized_options = b'\202\347\260*\006signer'
  _globals['_MSGMIGRATECONTRACT']._loaded_options = None
  _globals['_MSGMIGRATECONTRACT']._serialized_options = b'\202\347\260*\006signer'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSTORECODE']._serialized_start=88
  _globals['_MSGSTORECODE']._serialized_end=177
  _globals['_MSGSTORECODERESPONSE']._serialized_start=179
  _globals['_MSGSTORECODERESPONSE']._serialized_end=229
  _globals['_MSGREMOVECHECKSUM']._serialized_start=231
  _globals['_MSGREMOVECHECKSUM']._serialized_end=315
  _globals['_MSGREMOVECHECKSUMRESPONSE']._serialized_start=317
  _globals['_MSGREMOVECHECKSUMRESPONSE']._serialized_end=344
  _globals['_MSGMIGRATECONTRACT']._serialized_start=347
  _globals['_MSGMIGRATECONTRACT']._serialized_end=479
  _globals['_MSGMIGRATECONTRACTRESPONSE']._serialized_start=481
  _globals['_MSGMIGRATECONTRACTRESPONSE']._serialized_end=509
  _globals['_MSG']._serialized_start=512
  _globals['_MSG']._serialized_end=860
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/metadata.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ibc/applications/fee/v1/metadata.proto\x12\x17ibc.applications.fee.v1\"L\n\x08Metadata\x12\x1f\n\x0b\x66\x65\x65_version\x18\x01 \x01(\tR\nfeeVersion\x12\x1f\n\x0b\x61pp_version\x18\x02 \x01(\tR\nappVersionB\xe2\x01\n\x1b\x63om.ibc.applications.fee.v1B\rMetadataProtoP\x01Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\xa2\x02\x03IAF\xaa\x02\x17Ibc.Applications.Fee.V1\xca\x02\x17Ibc\\Applications\\Fee\\V1\xe2\x02#Ibc\\Applications\\Fee\\V1\\GPBMetadata\xea\x02\x1aIbc::Applications::Fee::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.ibc.applications.fee.v1B\rMetadataProtoP\001Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\242\002\003IAF\252\002\027Ibc.Applications.Fee.V1\312\002\027Ibc\\Applications\\Fee\\V1\342\002#Ibc\\Applications\\Fee\\V1\\GPBMetadata\352\002\032Ibc::Applications::Fee::V1'
  _globals['_METADATA']._serialized_start=67
  _globals['_METADATA']._serialized_end=143
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.exchange import (
    injective_insurance_rpc_pb2 as exchange_insurance_pb,
    injective_insurance_rpc_pb2_grpc as exchange_insurance_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IndexerGrpcInsuranceApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = self._stub = exchange_insurance_grpc.InjectiveInsuranceRPCStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_insurance_funds(self) -> Dict[str, Any]:
        request = exchange_insurance_pb.FundsRequest()
        response = await self._execute_call(call=self._stub.Funds, request=request)

        return response

    async def fetch_redemptions(
        self,
        address: Optional[str] = None,
        denom: Optional[str] = None,
        status: Optional[str] = None,
    ) -> Dict[str, Any]:
        request = exchange_insurance_pb.RedemptionsRequest(
            redeemer=address,
            redemption_denom=denom,
            status=status,
        )
        response = await self._execute_call(call=self._stub.Redemptions, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/wasm/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ibc/lightclients/wasm/v1/genesis.proto\x12\x18ibc.lightclients.wasm.v1\x1a\x14gogoproto/gogo.proto\"V\n\x0cGenesisState\x12\x46\n\tcontracts\x18\x01 \x03(\x0b\x32\".ibc.lightclients.wasm.v1.ContractB\x04\xc8\xde\x1f\x00R\tcontracts\"/\n\x08\x43ontract\x12\x1d\n\ncode_bytes\x18\x01 \x01(\x0cR\tcodeBytes:\x04\x88\xa0\x1f\x00\x42\xed\x01\n\x1c\x63om.ibc.lightclients.wasm.v1B\x0cGenesisProtoP\x01Z<github.com/cosmos/ibc-go/modules/light-clients/08-wasm/types\xa2\x02\x03ILW\xaa\x02\x18Ibc.Lightclients.Wasm.V1\xca\x02\x18Ibc\\Lightclients\\Wasm\\V1\xe2\x02$Ibc\\Lightclients\\Wasm\\V1\\GPBMetadata\xea\x02\x1bIbc::Lightclients::Wasm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.wasm.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.ibc.lightclients.wasm.v1B\014GenesisProtoP\001Z<github.com/cosmos/ibc-go/modules/light-clients/08-wasm/types\242\002\003ILW\252\002\030Ibc.Lightclients.Wasm.V1\312\002\030Ibc\\Lightclients\\Wasm\\V1\342\002$Ibc\\Lightclients\\Wasm\\V1\\GPBMetadata\352\002\033Ibc::Lightclients::Wasm::V1'
  _globals['_GENESISSTATE'].fields_by_name['contracts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['contracts']._serialized_options = b'\310\336\037\000'
  _globals['_CONTRACT']._loaded_options = None
  _globals['_CONTRACT']._serialized_options = b'\210\240\037\000'
  _globals['_GENESISSTATE']._serialized_start=90
  _globals['_GENESISSTATE']._serialized_end=176
  _globals['_CONTRACT']._serialized_start=178
  _globals['_CONTRACT']._serialized_end=225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v2/orderbook.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.exchange.v2 import order_pb2 as injective_dot_exchange_dot_v2_dot_order__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/exchange/v2/orderbook.proto\x12\x15injective.exchange.v2\x1a\x14gogoproto/gogo.proto\x1a!injective/exchange/v2/order.proto\"\x93\x01\n\rSpotOrderBook\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1c\n\tisBuySide\x18\x02 \x01(\x08R\tisBuySide\x12=\n\x06orders\x18\x03 \x03(\x0b\x32%.injective.exchange.v2.SpotLimitOrderR\x06orders:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x9f\x01\n\x13\x44\x65rivativeOrderBook\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x1c\n\tisBuySide\x18\x02 \x01(\x08R\tisBuySide\x12\x43\n\x06orders\x18\x03 \x03(\x0b\x32+.injective.exchange.v2.DerivativeLimitOrderR\x06orders:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xad\x03\n\x1e\x43onditionalDerivativeOrderBook\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12U\n\x10limit_buy_orders\x18\x02 \x03(\x0b\x32+.injective.exchange.v2.DerivativeLimitOrderR\x0elimitBuyOrders\x12X\n\x11market_buy_orders\x18\x03 \x03(\x0b\x32,.injective.exchange.v2.DerivativeMarketOrderR\x0fmarketBuyOrders\x12W\n\x11limit_sell_orders\x18\x04 \x03(\x0b\x32+.injective.exchange.v2.DerivativeLimitOrderR\x0flimitSellOrders\x12Z\n\x12market_sell_orders\x18\x05 \x03(\x0b\x32,.injective.exchange.v2.DerivativeMarketOrderR\x10marketSellOrders:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xfc\x03\n\x1bSubaccountOrderbookMetadata\x12\x39\n\x19vanilla_limit_order_count\x18\x01 \x01(\rR\x16vanillaLimitOrderCount\x12@\n\x1dreduce_only_limit_order_count\x18\x02 \x01(\rR\x19reduceOnlyLimitOrderCount\x12h\n\x1e\x61ggregate_reduce_only_quantity\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x1b\x61ggregateReduceOnlyQuantity\x12\x61\n\x1a\x61ggregate_vanilla_quantity\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x18\x61ggregateVanillaQuantity\x12\x45\n\x1fvanilla_conditional_order_count\x18\x05 \x01(\rR\x1cvanillaConditionalOrderCount\x12L\n#reduce_only_conditional_order_count\x18\x06 \x01(\rR\x1freduceOnlyConditionalOrderCountB\xf4\x01\n\x19\x63om.injective.exchange.v2B\x0eOrderbookProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\xa2\x02\x03IEX\xaa\x02\x15Injective.Exchange.V2\xca\x02\x15Injective\\Exchange\\V2\xe2\x02!Injective\\Exchange\\V2\\GPBMetadata\xea\x02\x17Injective::Exchange::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v2.orderbook_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective.exchange.v2B\016OrderbookProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types/v2\242\002\003IEX\252\002\025Injective.Exchange.V2\312\002\025Injective\\Exchange\\V2\342\002!Injective\\Exchange\\V2\\GPBMetadata\352\002\027Injective::Exchange::V2'
  _globals['_SPOTORDERBOOK']._loaded_options = None
  _globals['_SPOTORDERBOOK']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_DERIVATIVEORDERBOOK']._loaded_options = None
  _globals['_DERIVATIVEORDERBOOK']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_CONDITIONALDERIVATIVEORDERBOOK']._loaded_options = None
  _globals['_CONDITIONALDERIVATIVEORDERBOOK']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_SUBACCOUNTORDERBOOKMETADATA'].fields_by_name['aggregate_reduce_only_quantity']._loaded_options = None
  _globals['_SUBACCOUNTORDERBOOKMETADATA'].fields_by_name['aggregate_reduce_only_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SUBACCOUNTORDERBOOKMETADATA'].fields_by_name['aggregate_vanilla_quantity']._loaded_options = None
  _globals['_SUBACCOUNTORDERBOOKMETADATA'].fields_by_name['aggregate_vanilla_quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SPOTORDERBOOK']._serialized_start=122
  _globals['_SPOTORDERBOOK']._serialized_end=269
  _globals['_DERIVATIVEORDERBOOK']._serialized_start=272
  _globals['_DERIVATIVEORDERBOOK']._serialized_end=431
  _globals['_CONDITIONALDERIVATIVEORDERBOOK']._serialized_start=434
  _globals['_CONDITIONALDERIVATIVEORDERBOOK']._serialized_end=863
  _globals['_SUBACCOUNTORDERBOOKMETADATA']._serialized_start=866
  _globals['_SUBACCOUNTORDERBOOKMETADATA']._serialized_end=1374
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import event_provider_api_pb2 as exchange_dot_event__provider__api__pb2


class EventProviderAPIStub(object):
    """EventProviderAPI provides processed block events for different backends.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetLatestHeight = channel.unary_unary(
                '/event_provider_api.EventProviderAPI/GetLatestHeight',
                request_serializer=exchange_dot_event__provider__api__pb2.GetLatestHeightRequest.SerializeToString,
                response_deserializer=exchange_dot_event__provider__api__pb2.GetLatestHeightResponse.FromString,
                _registered_method=True)
        self.StreamLatestHeight = channel.unary_stream(
                '/event_provider_api.EventProviderAPI/StreamLatestHeight',
                request_serializer=exchange_dot_event__provider__api__pb2.StreamLatestHeightRequest.SerializeToString,
                response_deserializer=exchange_dot_event__provider__api__pb2.StreamLatestHeightResponse.FromString,
                _registered_method=True)
        self.StreamBlockEvents = channel.unary_stream(
                '/event_provider_api.EventProviderAPI/StreamBlockEvents',
                request_serializer=exchange_dot_event__provider__api__pb2.StreamBlockEventsRequest.SerializeToString,
                response_deserializer=exchange_dot_event__provider__api__pb2.StreamBlockEventsResponse.FromString,
                _registered_method=True)
        self.GetBlockEventsRPC = channel.unary_unary(
                '/event_provider_api.EventProviderAPI/GetBlockEventsRPC',
                request_serializer=exchange_dot_event__provider__api__pb2.GetBlockEventsRPCRequest.SerializeToString,
                response_deserializer=exchange_dot_event__provider__api__pb2.GetBlockEventsRPCResponse.FromString,
                _registered_method=True)
        self.GetCustomEventsRPC = channel.unary_unary(
                '/event_provider_api.EventProviderAPI/GetCustomEventsRPC',
                request_serializer=exchange_dot_event__provider__api__pb2.GetCustomEventsRPCRequest.SerializeToString,
                response_deserializer=exchange_dot_event__provider__api__pb2.GetCustomEventsRPCResponse.FromString,
                _registered_method=True)
        self.GetABCIBlockEvents = channel.unary_unary(
                '/event_provider_api.EventProviderAPI/GetABCIBlockEvents',
                request_serializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsRequest.SerializeToString,
                response_deserializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsResponse.FromString,
                _registered_method=True)
        self.GetABCIBlockEventsAtHeight = channel.unary_unary(
                '/event_provider_api.EventProviderAPI/GetABCIBlockEventsAtHeight',
                request_serializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsAtHeightRequest.SerializeToString,
                response_deserializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsAtHeightResponse.FromString,
                _registered_method=True)


class EventProviderAPIServicer(object):
    """EventProviderAPI provides processed block events for different backends.
    """

    def GetLatestHeight(self, request, context):
        """Get latest block from event provider
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamLatestHeight(self, request, context):
        """Stream latest block information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamBlockEvents(self, request, context):
        """Stream processed block events for selected backend
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockEventsRPC(self, request, context):
        """Get processed block events for selected backend
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCustomEventsRPC(self, request, context):
        """Get custom processed block events for selected backend
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetABCIBlockEvents(self, request, context):
        """Get raw block events for selected height
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetABCIBlockEventsAtHeight(self, request, context):
        """Get all raw block events for selected height
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EventProviderAPIServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetLatestHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestHeight,
                    request_deserializer=exchange_dot_event__provider__api__pb2.GetLatestHeightRequest.FromString,
                    response_serializer=exchange_dot_event__provider__api__pb2.GetLatestHeightResponse.SerializeToString,
            ),
            'StreamLatestHeight': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamLatestHeight,
                    request_deserializer=exchange_dot_event__provider__api__pb2.StreamLatestHeightRequest.FromString,
                    response_serializer=exchange_dot_event__provider__api__pb2.StreamLatestHeightResponse.SerializeToString,
            ),
            'StreamBlockEvents': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamBlockEvents,
                    request_deserializer=exchange_dot_event__provider__api__pb2.StreamBlockEventsRequest.FromString,
                    response_serializer=exchange_dot_event__provider__api__pb2.StreamBlockEventsResponse.SerializeToString,
            ),
            'GetBlockEventsRPC': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockEventsRPC,
                    request_deserializer=exchange_dot_event__provider__api__pb2.GetBlockEventsRPCRequest.FromString,
                    response_serializer=exchange_dot_event__provider__api__pb2.GetBlockEventsRPCResponse.SerializeToString,
            ),
            'GetCustomEventsRPC': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCustomEventsRPC,
                    request_deserializer=exchange_dot_event__provider__api__pb2.GetCustomEventsRPCRequest.FromString,
                    response_serializer=exchange_dot_event__provider__api__pb2.GetCustomEventsRPCResponse.SerializeToString,
            ),
            'GetABCIBlockEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.GetABCIBlockEvents,
                    request_deserializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsRequest.FromString,
                    response_serializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsResponse.SerializeToString,
            ),
            'GetABCIBlockEventsAtHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetABCIBlockEventsAtHeight,
                    request_deserializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsAtHeightRequest.FromString,
                    response_serializer=exchange_dot_event__provider__api__pb2.GetABCIBlockEventsAtHeightResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'event_provider_api.EventProviderAPI', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('event_provider_api.EventProviderAPI', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class EventProviderAPI(object):
    """EventProviderAPI provides processed block events for different backends.
    """

    @staticmethod
    def GetLatestHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/event_provider_api.EventProviderAPI/GetLatestHeight',
            exchange_dot_event__provider__api__pb2.GetLatestHeightRequest.SerializeToString,
            exchange_dot_event__provider__api__pb2.GetLatestHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamLatestHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/event_provider_api.EventProviderAPI/StreamLatestHeight',
            exchange_dot_event__provider__api__pb2.StreamLatestHeightRequest.SerializeToString,
            exchange_dot_event__provider__api__pb2.StreamLatestHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamBlockEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/event_provider_api.EventProviderAPI/StreamBlockEvents',
            exchange_dot_event__provider__api__pb2.StreamBlockEventsRequest.SerializeToString,
            exchange_dot_event__provider__api__pb2.StreamBlockEventsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockEventsRPC(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/event_provider_api.EventProviderAPI/GetBlockEventsRPC',
            exchange_dot_event__provider__api__pb2.GetBlockEventsRPCRequest.SerializeToString,
            exchange_dot_event__provider__api__pb2.GetBlockEventsRPCResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCustomEventsRPC(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/event_provider_api.EventProviderAPI/GetCustomEventsRPC',
            exchange_dot_event__provider__api__pb2.GetCustomEventsRPCRequest.SerializeToString,
            exchange_dot_event__provider__api__pb2.GetCustomEventsRPCResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetABCIBlockEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/event_provider_api.EventProviderAPI/GetABCIBlockEvents',
            exchange_dot_event__provider__api__pb2.GetABCIBlockEventsRequest.SerializeToString,
            exchange_dot_event__provider__api__pb2.GetABCIBlockEventsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetABCIBlockEventsAtHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/event_provider_api.EventProviderAPI/GetABCIBlockEventsAtHeight',
            exchange_dot_event__provider__api__pb2.GetABCIBlockEventsAtHeightRequest.SerializeToString,
            exchange_dot_event__provider__api__pb2.GetABCIBlockEventsAtHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/privval/v1beta2/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.crypto.v1 import keys_pb2 as cometbft_dot_crypto_dot_v1_dot_keys__pb2
from pyinjective.proto.cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cometbft/privval/v1beta2/types.proto\x12\x18\x63ometbft.privval.v1beta2\x1a\x1d\x63ometbft/crypto/v1/keys.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x14gogoproto/gogo.proto\"I\n\x11RemoteSignerError\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"*\n\rPubKeyRequest\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\tR\x07\x63hainId\"\x91\x01\n\x0ePubKeyResponse\x12<\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1d.cometbft.crypto.v1.PublicKeyB\x04\xc8\xde\x1f\x00R\x06pubKey\x12\x41\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerErrorR\x05\x65rror\"Y\n\x0fSignVoteRequest\x12+\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteR\x04vote\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\"\x8a\x01\n\x12SignedVoteResponse\x12\x31\n\x04vote\x18\x01 \x01(\x0b\x32\x17.cometbft.types.v1.VoteB\x04\xc8\xde\x1f\x00R\x04vote\x12\x41\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerErrorR\x05\x65rror\"i\n\x13SignProposalRequest\x12\x37\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalR\x08proposal\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\"\x9a\x01\n\x16SignedProposalResponse\x12=\n\x08proposal\x18\x01 \x01(\x0b\x32\x1b.cometbft.types.v1.ProposalB\x04\xc8\xde\x1f\x00R\x08proposal\x12\x41\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta2.RemoteSignerErrorR\x05\x65rror\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xe2\x05\n\x07Message\x12Q\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32\'.cometbft.privval.v1beta2.PubKeyRequestH\x00R\rpubKeyRequest\x12T\n\x10pub_key_response\x18\x02 \x01(\x0b\x32(.cometbft.privval.v1beta2.PubKeyResponseH\x00R\x0epubKeyResponse\x12W\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32).cometbft.privval.v1beta2.SignVoteRequestH\x00R\x0fsignVoteRequest\x12`\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32,.cometbft.privval.v1beta2.SignedVoteResponseH\x00R\x12signedVoteResponse\x12\x63\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32-.cometbft.privval.v1beta2.SignProposalRequestH\x00R\x13signProposalRequest\x12l\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32\x30.cometbft.privval.v1beta2.SignedProposalResponseH\x00R\x16signedProposalResponse\x12J\n\x0cping_request\x18\x07 \x01(\x0b\x32%.cometbft.privval.v1beta2.PingRequestH\x00R\x0bpingRequest\x12M\n\rping_response\x18\x08 \x01(\x0b\x32&.cometbft.privval.v1beta2.PingResponseH\x00R\x0cpingResponseB\x05\n\x03sum*\xa8\x01\n\x06\x45rrors\x12\x12\n\x0e\x45RRORS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x45RRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14\x45RRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19\x45RRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13\x45RRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14\x45RRORS_WRITE_TIMEOUT\x10\x05\x42\xe7\x01\n\x1c\x63om.cometbft.privval.v1beta2B\nTypesProtoP\x01Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta2\xa2\x02\x03\x43PX\xaa\x02\x18\x43ometbft.Privval.V1beta2\xca\x02\x18\x43ometbft\\Privval\\V1beta2\xe2\x02$Cometbft\\Privval\\V1beta2\\GPBMetadata\xea\x02\x1a\x43ometbft::Privval::V1beta2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.privval.v1beta2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.cometbft.privval.v1beta2B\nTypesProtoP\001Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta2\242\002\003CPX\252\002\030Cometbft.Privval.V1beta2\312\002\030Cometbft\\Privval\\V1beta2\342\002$Cometbft\\Privval\\V1beta2\\GPBMetadata\352\002\032Cometbft::Privval::V1beta2'
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._loaded_options = None
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._loaded_options = None
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_ERRORS']._serialized_start=1686
  _globals['_ERRORS']._serialized_end=1854
  _globals['_REMOTESIGNERERROR']._serialized_start=150
  _globals['_REMOTESIGNERERROR']._serialized_end=223
  _globals['_PUBKEYREQUEST']._serialized_start=225
  _globals['_PUBKEYREQUEST']._serialized_end=267
  _globals['_PUBKEYRESPONSE']._serialized_start=270
  _globals['_PUBKEYRESPONSE']._serialized_end=415
  _globals['_SIGNVOTEREQUEST']._serialized_start=417
  _globals['_SIGNVOTEREQUEST']._serialized_end=506
  _globals['_SIGNEDVOTERESPONSE']._serialized_start=509
  _globals['_SIGNEDVOTERESPONSE']._serialized_end=647
  _globals['_SIGNPROPOSALREQUEST']._serialized_start=649
  _globals['_SIGNPROPOSALREQUEST']._serialized_end=754
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_start=757
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_end=911
  _globals['_PINGREQUEST']._serialized_start=913
  _globals['_PINGREQUEST']._serialized_end=926
  _globals['_PINGRESPONSE']._serialized_start=928
  _globals['_PINGRESPONSE']._serialized_end=942
  _globals['_MESSAGE']._serialized_start=945
  _globals['_MESSAGE']._serialized_end=1683
# @@protoc_insertion_point(module_scope)
